/**
 * @Copyright (c) Microsoft Corporation.  All rights reserved.
 *
 * @file Client side Application manifest definition.
 */
import { IClientSideComponentManifest, ILocalizedString } from './IClientSideComponentManifest';
/**
 * This is the manifest for a client-side application.
 *
 * @alpha
 */
export interface IClientSideApplicationManifest extends IClientSideComponentManifest {
    /**
     * Represents flags to preload information in host aspx page.
     */
    preloadOptions: IPreloadOptions;
    /**
     * Definition: Title of the application as a dictionary of locale keys to title values. This value will be
     *  displayed to the user in the (page creation) interface.
     * Required: yes
     * Supported values: a dictionary of locale keys to strings. Should always have a 'default' key.
     * Example: "My Application"
     *          {
     *            "default": "My Application"
     *            "en-us": "My Application",
     *            "fr-fr": "Ma demande",
     *            "zh": "我的應用程式"
     *          }
     */
    title: ILocalizedString;
    /**
     * Definition: Description of the application represented as a dictionary of locale keys to description values.
     *  This value will be displayed to the user in the (page creation) interface.
     * Required: yes
     * Supported values: a dictionary of locale keys to strings. Should always have a 'default' key.
     * Example: "An application for searching for things."
     *          {
     *            "default": "An application for searching for things.",
     *            "en-us": "An application for searching for things.",
     *            "fr-fr": "Une demande pour la recherche de choses.",
     *            "zh": "申請尋找的東西。"
     *          }
     */
    description: ILocalizedString;
    /**
     * Definition: A list of component manifests that must be preloaded alongside this application. These may include
     *  external resources or Web Parts that are needed during initial render.
     * Required: yes
     * Supported values: an array of manifest IDs
     * Example: [ "66665f5e-307f-41cf-9fec-17c5ea20f0ca", "2d02eafb-eb82-47d2-98ac-dcac4aa63969" ]
     */
    preloadComponents: string[];
    /**
     * Definition: Id of the preferred assembly to use to load the application.
     * If no assembly id is provided SPFx will be loaded with the default assembly.
     * Required: no
     * Supported values: any GUID
     * Example: "44bae1a2-d2eb-4e10-8c21-a1dbdce1036f"
     * @internal
     */
    assemblyId?: string;
}
/**
 * @alpha
 */
export interface IPreloadOptions {
    /**
     * Definition: A value indicating whether or not to preload the web object when loading the application page.
     *  If not present, defaults to false.
     * Usage: Determines whether or not to preload the web object.
     * Required: no
     * Supported values: true, false
     * Example: true
     */
    shouldPreloadWeb?: boolean;
    /**
     * Definition: A value indicating whether or not to preload the user object when loading the application page.
     *  If not present, defaults to false.
     * Usage: Determines whether or not to preload the user object.
     * Required: no
     * Supported values: true, false
     * Example: true
     */
    shouldPreloadUser?: boolean;
    /**
     * Definition: A value indicating whether or not to preload the list object when loading the application page.
     *  If not present, defaults to false.
     * Usage: Determines whether or not to preload the list object.
     * Required: no
     * Supported values: true, false
     * Example: true
     */
    shouldPreloadList?: boolean;
    /**
     * Definition: A value indicating whether or not to preload the list item object when loading the application page.
     *  If not present, defaults to false.
     * Usage: Determines whether or not to preload the list item object.
     * Required: no
     * Supported values: true, false
     * Example: true
     */
    shouldPreloadItem?: boolean;
    /**
     * Definition: A value indicating whether or not to preload the quick launch navigation menu items when loading the
     *  application page. If not present, defaults to false.
     * Usage: Determines whether or not to preload the quick launch navigation menu items.
     * Required: no
     * Supported values: true, false
     * Example: true
     */
    shouldPreloadQuickLaunch?: boolean;
    /**
     * Definition: This specifies an optional OData query expression with the syntax that would be used
     * in the URL query parameter for a REST API call that fetches a SharePoint list item.
     * It enables the application to tailor the way the preload object will be serialized.
     * For example, if you want to include the custom fields MyField1 and MyField2 and expand
     * the Folder property, the preloadListItemQueryOption would look like this
     * "$select=MyField1,MyField2&$expand=Folder"
     * Usage: This specifies an optional OData query expression
     * Required: no
     * Supported values: A query following the CAML standard
     * Example: "$select=MyField1,MyField2&$expand=Folder"
     */
    preloadListItemQueryOption?: string;
}
